package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.TypePutInStorageDetails;
import com.bonus.material.ma.service.ITypePutInStorageDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 盘点入库详情Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "盘点入库详情接口")
@RestController
@RequestMapping("/ma_type_put_in_storage_details")
public class TypePutInStorageDetailsController extends BaseController
{
    @Autowired
    private ITypePutInStorageDetailsService typePutInStorageDetailsService;

    /**
     * 查询盘点入库详情列表
     */
    @ApiOperation(value = "查询盘点入库详情列表")
    @RequiresPermissions("ma:details:list")
    @GetMapping("/list")
    public TableDataInfo list(TypePutInStorageDetails typePutInStorageDetails)
    {
        startPage();
        List<TypePutInStorageDetails> list = typePutInStorageDetailsService.selectTypePutInStorageDetailsList(typePutInStorageDetails);
        return getDataTable(list);
    }

    /**
     * 导出盘点入库详情列表
     */
    @ApiOperation(value = "导出盘点入库详情列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:details:export")
    @SysLog(title = "盘点入库详情", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出盘点入库详情")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TypePutInStorageDetails typePutInStorageDetails)
    {
        List<TypePutInStorageDetails> list = typePutInStorageDetailsService.selectTypePutInStorageDetailsList(typePutInStorageDetails);
        ExcelUtil<TypePutInStorageDetails> util = new ExcelUtil<TypePutInStorageDetails>(TypePutInStorageDetails.class);
        util.exportExcel(response, list, "盘点入库详情数据");
    }

    /**
     * 获取盘点入库详情详细信息
     */
    @ApiOperation(value = "获取盘点入库详情详细信息")
    @RequiresPermissions("ma:details:query")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(typePutInStorageDetailsService.selectTypePutInStorageDetailsByID(ID));
    }

    /**
     * 新增盘点入库详情
     */
    @ApiOperation(value = "新增盘点入库详情")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:details:add")
    @SysLog(title = "盘点入库详情", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增盘点入库详情")
    @PostMapping
    public AjaxResult add(@RequestBody TypePutInStorageDetails typePutInStorageDetails)
    {
        return toAjax(typePutInStorageDetailsService.insertTypePutInStorageDetails(typePutInStorageDetails));
    }

    /**
     * 修改盘点入库详情
     */
    @ApiOperation(value = "修改盘点入库详情")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:details:edit")
    @SysLog(title = "盘点入库详情", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改盘点入库详情")
    @PutMapping
    public AjaxResult edit(@RequestBody TypePutInStorageDetails typePutInStorageDetails)
    {
        return toAjax(typePutInStorageDetailsService.updateTypePutInStorageDetails(typePutInStorageDetails));
    }

    /**
     * 删除盘点入库详情
     */
    @ApiOperation(value = "删除盘点入库详情")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:details:remove")
    @SysLog(title = "盘点入库详情", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除盘点入库详情")
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(typePutInStorageDetailsService.deleteTypePutInStorageDetailsByIDs(IDs));
    }
}
